@@ -116,7 +116,7 @@ def _get_one_batch_after_timestamp(data_source, latest_timestamp):
 
 def start_processor(process, consumer, data_source):
     latest_timestamp = _get_latest_processed_timestamp(f'{consumer}-{data_source}')  # from state
-    event_loop = asyncio.get_event_loop()
+    event_loop = asyncio.get_event_loop()  # this will be deprecated in 3.10
     while True:
         print('latest_timestamp before : ', latest_timestamp)
         batch, latest_timestamp, file_name, metadata = _get_one_batch_after_timestamp(data_source, latest_timestamp)
