@@ -1,3 +1,5 @@
+import gzip
+import base64
 import boto3
 import json
 
@@ -12,7 +14,13 @@ client = boto3.client(
 )
 
 
-def publish(topic, body=None, path=None, json_encoder=None) -> None:
+def gzip_utf8_compress(data):
+    compressed_bytes = gzip.compress(bytes(data, 'utf-8'))
+    compressed_string = base64.b64encode(compressed_bytes).decode('utf-8')
+    return compressed_string
+
+
+def publish(topic, body=None, path=None, json_encoder=None, compression=None) -> None:
     message = {
         'body': body,
         'path': path,
@@ -23,6 +31,9 @@ def publish(topic, body=None, path=None, json_encoder=None) -> None:
     #     message['trace_id'] = segment.trace_id
 
     message = json.dumps(message, cls=json_encoder)
+    if compression == 'gzip':
+        message = gzip_utf8_compress(message)
+
     message = json.dumps({"default": message})
 
     env = 'dev' if settings.ENVIRONMENT == 'local' else settings.ENVIRONMENT
